import typing

import java
import java.chaquopy
import java.lang
import java.util

class JSONArray(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, array: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def __init__(self, json: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, copyFrom: java.util.Collection, /) -> None: ...
    @typing.overload
    def __init__(self, readFrom: JSONTokener, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def get(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getBoolean(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getDouble(self, index: int | java.jint | java.lang.Integer, /) -> float: ...
    def getInt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getJSONArray(self, index: int | java.jint | java.lang.Integer, /) -> JSONArray: ...
    def getJSONObject(self, index: int | java.jint | java.lang.Integer, /) -> JSONObject: ...
    def getLong(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def hashCode(self) -> int: ...
    def isNull(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def join(self, separator: str | java.lang.String, /) -> str: ...
    def length(self) -> int: ...
    def opt(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    @typing.overload
    def optBoolean(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def optBoolean(self, index: int | java.jint | java.lang.Integer, fallback: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def optDouble(self, index: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def optDouble(self, index: int | java.jint | java.lang.Integer, fallback: float | java.jdouble | java.lang.Double, /) -> float: ...
    @typing.overload
    def optInt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def optInt(self, index: int | java.jint | java.lang.Integer, fallback: int | java.jint | java.lang.Integer, /) -> int: ...
    def optJSONArray(self, index: int | java.jint | java.lang.Integer, /) -> JSONArray: ...
    def optJSONObject(self, index: int | java.jint | java.lang.Integer, /) -> JSONObject: ...
    @typing.overload
    def optLong(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def optLong(self, index: int | java.jint | java.lang.Integer, fallback: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def optString(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def optString(self, index: int | java.jint | java.lang.Integer, fallback: str | java.lang.String, /) -> str: ...
    @typing.overload
    def put(self, value: float | java.jdouble | java.lang.Double, /) -> JSONArray: ...
    @typing.overload
    def put(self, value: int | java.jint | java.lang.Integer, /) -> JSONArray: ...
    @typing.overload
    def put(self, value: int | java.jlong | java.lang.Long, /) -> JSONArray: ...
    @typing.overload
    def put(self, value: java.lang.Object | int | bool | float | str, /) -> JSONArray: ...
    @typing.overload
    def put(self, value: bool | java.jboolean | java.lang.Boolean, /) -> JSONArray: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, value: float | java.jdouble | java.lang.Double, /) -> JSONArray: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> JSONArray: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, value: int | java.jlong | java.lang.Long, /) -> JSONArray: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, value: java.lang.Object | int | bool | float | str, /) -> JSONArray: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, value: bool | java.jboolean | java.lang.Boolean, /) -> JSONArray: ...
    def remove(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def toJSONObject(self, names: JSONArray, /) -> JSONObject: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, indentSpaces: int | java.jint | java.lang.Integer, /) -> str: ...

class JSONException(java.lang.Exception):
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class JSONObject(java.lang.Object):
    NULL: typing.ClassVar[java.lang.Object] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, json: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, copyFrom: java.util.Map, /) -> None: ...
    @typing.overload
    def __init__(self, readFrom: JSONTokener, /) -> None: ...
    @typing.overload
    def __init__(self, copyFrom: JSONObject, names: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def accumulate(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> JSONObject: ...
    def append(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> JSONObject: ...
    def get(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def getBoolean(self, name: str | java.lang.String, /) -> bool: ...
    def getDouble(self, name: str | java.lang.String, /) -> float: ...
    def getInt(self, name: str | java.lang.String, /) -> int: ...
    def getJSONArray(self, name: str | java.lang.String, /) -> JSONArray: ...
    def getJSONObject(self, name: str | java.lang.String, /) -> JSONObject: ...
    def getLong(self, name: str | java.lang.String, /) -> int: ...
    def getString(self, name: str | java.lang.String, /) -> str: ...
    def has(self, name: str | java.lang.String, /) -> bool: ...
    def isNull(self, name: str | java.lang.String, /) -> bool: ...
    def keys(self) -> java.util.Iterator[java.lang.String]: ...
    def length(self) -> int: ...
    def names(self) -> JSONArray: ...
    @staticmethod
    def numberToString(number: java.lang.Number, /) -> str: ...
    def opt(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    @typing.overload
    def optBoolean(self, name: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def optBoolean(self, name: str | java.lang.String, fallback: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def optDouble(self, name: str | java.lang.String, /) -> float: ...
    @typing.overload
    def optDouble(self, name: str | java.lang.String, fallback: float | java.jdouble | java.lang.Double, /) -> float: ...
    @typing.overload
    def optInt(self, name: str | java.lang.String, /) -> int: ...
    @typing.overload
    def optInt(self, name: str | java.lang.String, fallback: int | java.jint | java.lang.Integer, /) -> int: ...
    def optJSONArray(self, name: str | java.lang.String, /) -> JSONArray: ...
    def optJSONObject(self, name: str | java.lang.String, /) -> JSONObject: ...
    @typing.overload
    def optLong(self, name: str | java.lang.String, /) -> int: ...
    @typing.overload
    def optLong(self, name: str | java.lang.String, fallback: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def optString(self, name: str | java.lang.String, /) -> str: ...
    @typing.overload
    def optString(self, name: str | java.lang.String, fallback: str | java.lang.String, /) -> str: ...
    @typing.overload
    def put(self, name: str | java.lang.String, value: float | java.jdouble | java.lang.Double, /) -> JSONObject: ...
    @typing.overload
    def put(self, name: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> JSONObject: ...
    @typing.overload
    def put(self, name: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> JSONObject: ...
    @typing.overload
    def put(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> JSONObject: ...
    @typing.overload
    def put(self, name: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> JSONObject: ...
    def putOpt(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> JSONObject: ...
    @staticmethod
    def quote(data: str | java.lang.String, /) -> str: ...
    def remove(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def toJSONArray(self, names: JSONArray, /) -> JSONArray: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, indentSpaces: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def wrap(o: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...

class JSONStringer(java.lang.Object):
    def __init__(self) -> None: ...
    def array(self) -> JSONStringer: ...
    def endArray(self) -> JSONStringer: ...
    def endObject(self) -> JSONStringer: ...
    def key(self, name: str | java.lang.String, /) -> JSONStringer: ...
    def object(self) -> JSONStringer: ...
    def toString(self) -> str: ...
    @typing.overload
    def value(self, value: float | java.jdouble | java.lang.Double, /) -> JSONStringer: ...
    @typing.overload
    def value(self, value: int | java.jlong | java.lang.Long, /) -> JSONStringer: ...
    @typing.overload
    def value(self, value: java.lang.Object | int | bool | float | str, /) -> JSONStringer: ...
    @typing.overload
    def value(self, value: bool | java.jboolean | java.lang.Boolean, /) -> JSONStringer: ...

class JSONTokener(java.lang.Object):
    def __init__(self, in_: str | java.lang.String, /) -> None: ...
    def back(self) -> None: ...
    @staticmethod
    def dehexchar(hex: str | java.jchar | java.lang.Character, /) -> int: ...
    def more(self) -> bool: ...
    @typing.overload
    def next(self) -> str: ...
    @typing.overload
    def next(self, c: str | java.jchar | java.lang.Character, /) -> str: ...
    @typing.overload
    def next(self, length: int | java.jint | java.lang.Integer, /) -> str: ...
    def nextClean(self) -> str: ...
    def nextString(self, quote: str | java.jchar | java.lang.Character, /) -> str: ...
    @typing.overload
    def nextTo(self, excluded: str | java.jchar | java.lang.Character, /) -> str: ...
    @typing.overload
    def nextTo(self, excluded: str | java.lang.String, /) -> str: ...
    def nextValue(self) -> java.lang.Object: ...
    def skipPast(self, thru: str | java.lang.String, /) -> None: ...
    def skipTo(self, to: str | java.jchar | java.lang.Character, /) -> str: ...
    def syntaxError(self, message: str | java.lang.String, /) -> JSONException: ...
    def toString(self) -> str: ...



import typing

import android.app
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import java.util

class UsbAccessory(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UsbAccessory]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDescription(self) -> str | None: ...
    def getManufacturer(self) -> str: ...
    def getModel(self) -> str: ...
    def getSerial(self) -> str | None: ...
    def getUri(self) -> str | None: ...
    def getVersion(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UsbConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UsbConfiguration]] = ...
    def describeContents(self) -> int: ...
    def getId(self) -> int: ...
    def getInterface(self, index: int | java.jint | java.lang.Integer, /) -> UsbInterface: ...
    def getInterfaceCount(self) -> int: ...
    def getMaxPower(self) -> int: ...
    def getName(self) -> str | None: ...
    def isRemoteWakeup(self) -> bool: ...
    def isSelfPowered(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UsbConstants(java.lang.Object):
    USB_CLASS_APP_SPEC: typing.ClassVar[int] = ...
    USB_CLASS_AUDIO: typing.ClassVar[int] = ...
    USB_CLASS_CDC_DATA: typing.ClassVar[int] = ...
    USB_CLASS_COMM: typing.ClassVar[int] = ...
    USB_CLASS_CONTENT_SEC: typing.ClassVar[int] = ...
    USB_CLASS_CSCID: typing.ClassVar[int] = ...
    USB_CLASS_HID: typing.ClassVar[int] = ...
    USB_CLASS_HUB: typing.ClassVar[int] = ...
    USB_CLASS_MASS_STORAGE: typing.ClassVar[int] = ...
    USB_CLASS_MISC: typing.ClassVar[int] = ...
    USB_CLASS_PER_INTERFACE: typing.ClassVar[int] = ...
    USB_CLASS_PHYSICA: typing.ClassVar[int] = ...
    USB_CLASS_PRINTER: typing.ClassVar[int] = ...
    USB_CLASS_STILL_IMAGE: typing.ClassVar[int] = ...
    USB_CLASS_VENDOR_SPEC: typing.ClassVar[int] = ...
    USB_CLASS_VIDEO: typing.ClassVar[int] = ...
    USB_CLASS_WIRELESS_CONTROLLER: typing.ClassVar[int] = ...
    USB_DIR_IN: typing.ClassVar[int] = ...
    USB_DIR_OUT: typing.ClassVar[int] = ...
    USB_ENDPOINT_DIR_MASK: typing.ClassVar[int] = ...
    USB_ENDPOINT_NUMBER_MASK: typing.ClassVar[int] = ...
    USB_ENDPOINT_XFERTYPE_MASK: typing.ClassVar[int] = ...
    USB_ENDPOINT_XFER_BULK: typing.ClassVar[int] = ...
    USB_ENDPOINT_XFER_CONTROL: typing.ClassVar[int] = ...
    USB_ENDPOINT_XFER_INT: typing.ClassVar[int] = ...
    USB_ENDPOINT_XFER_ISOC: typing.ClassVar[int] = ...
    USB_INTERFACE_SUBCLASS_BOOT: typing.ClassVar[int] = ...
    USB_SUBCLASS_VENDOR_SPEC: typing.ClassVar[int] = ...
    USB_TYPE_CLASS: typing.ClassVar[int] = ...
    USB_TYPE_MASK: typing.ClassVar[int] = ...
    USB_TYPE_RESERVED: typing.ClassVar[int] = ...
    USB_TYPE_STANDARD: typing.ClassVar[int] = ...
    USB_TYPE_VENDOR: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...

class UsbDevice(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UsbDevice]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getConfiguration(self, index: int | java.jint | java.lang.Integer, /) -> UsbConfiguration: ...
    def getConfigurationCount(self) -> int: ...
    def getDeviceClass(self) -> int: ...
    @typing.overload
    def getDeviceId(self) -> int: ...
    @typing.overload
    @staticmethod
    def getDeviceId(name: str | java.lang.String, /) -> int: ...
    @typing.overload
    def getDeviceName(self) -> str: ...
    @typing.overload
    @staticmethod
    def getDeviceName(id: int | java.jint | java.lang.Integer, /) -> str: ...
    def getDeviceProtocol(self) -> int: ...
    def getDeviceSubclass(self) -> int: ...
    def getInterface(self, index: int | java.jint | java.lang.Integer, /) -> UsbInterface: ...
    def getInterfaceCount(self) -> int: ...
    def getManufacturerName(self) -> str | None: ...
    def getProductId(self) -> int: ...
    def getProductName(self) -> str | None: ...
    def getSerialNumber(self) -> str | None: ...
    def getVendorId(self) -> int: ...
    def getVersion(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UsbDeviceConnection(java.lang.Object):
    @typing.overload
    def bulkTransfer(self, endpoint: UsbEndpoint, buffer: java.chaquopy.JavaArrayJByte, length: int | java.jint | java.lang.Integer, timeout: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def bulkTransfer(self, endpoint: UsbEndpoint, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, timeout: int | java.jint | java.lang.Integer, /) -> int: ...
    def claimInterface(self, intf: UsbInterface, force: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def close(self) -> None: ...
    @typing.overload
    def controlTransfer(self, requestType: int | java.jint | java.lang.Integer, request: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, index: int | java.jint | java.lang.Integer, buffer: java.chaquopy.JavaArrayJByte, length: int | java.jint | java.lang.Integer, timeout: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def controlTransfer(self, requestType: int | java.jint | java.lang.Integer, request: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, index: int | java.jint | java.lang.Integer, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, timeout: int | java.jint | java.lang.Integer, /) -> int: ...
    def finalize(self) -> None: ...
    def getFileDescriptor(self) -> int: ...
    def getRawDescriptors(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSerial(self) -> str: ...
    def releaseInterface(self, intf: UsbInterface, /) -> bool: ...
    @typing.overload
    def requestWait(self) -> UsbRequest | None: ...
    @typing.overload
    def requestWait(self, timeout: int | java.jlong | java.lang.Long, /) -> UsbRequest | None: ...
    def setConfiguration(self, configuration: UsbConfiguration, /) -> bool: ...
    def setInterface(self, intf: UsbInterface, /) -> bool: ...

class UsbEndpoint(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UsbEndpoint]] = ...
    def describeContents(self) -> int: ...
    def getAddress(self) -> int: ...
    def getAttributes(self) -> int: ...
    def getDirection(self) -> int: ...
    def getEndpointNumber(self) -> int: ...
    def getInterval(self) -> int: ...
    def getMaxPacketSize(self) -> int: ...
    def getType(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UsbInterface(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UsbInterface]] = ...
    def describeContents(self) -> int: ...
    def getAlternateSetting(self) -> int: ...
    def getEndpoint(self, index: int | java.jint | java.lang.Integer, /) -> UsbEndpoint: ...
    def getEndpointCount(self) -> int: ...
    def getId(self) -> int: ...
    def getInterfaceClass(self) -> int: ...
    def getInterfaceProtocol(self) -> int: ...
    def getInterfaceSubclass(self) -> int: ...
    def getName(self) -> str | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UsbManager(java.lang.Object):
    ACTION_USB_ACCESSORY_ATTACHED: typing.ClassVar[str] = ...
    ACTION_USB_ACCESSORY_DETACHED: typing.ClassVar[str] = ...
    ACTION_USB_DEVICE_ATTACHED: typing.ClassVar[str] = ...
    ACTION_USB_DEVICE_DETACHED: typing.ClassVar[str] = ...
    EXTRA_ACCESSORY: typing.ClassVar[str] = ...
    EXTRA_DEVICE: typing.ClassVar[str] = ...
    EXTRA_PERMISSION_GRANTED: typing.ClassVar[str] = ...
    def getAccessoryList(self) -> java.chaquopy.JavaArray[UsbAccessory] | None: ...
    def getDeviceList(self) -> java.util.HashMap[java.lang.String, UsbDevice]: ...
    @typing.overload
    def hasPermission(self, accessory: UsbAccessory, /) -> bool: ...
    @typing.overload
    def hasPermission(self, device: UsbDevice, /) -> bool: ...
    def openAccessory(self, accessory: UsbAccessory, /) -> android.os.ParcelFileDescriptor | None: ...
    def openAccessoryInputStream(self, accessory: UsbAccessory, /) -> java.io.InputStream: ...
    def openAccessoryOutputStream(self, accessory: UsbAccessory, /) -> java.io.OutputStream: ...
    def openDevice(self, device: UsbDevice, /) -> UsbDeviceConnection: ...
    @typing.overload
    def requestPermission(self, accessory: UsbAccessory, pi: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def requestPermission(self, device: UsbDevice, pi: android.app.PendingIntent, /) -> None: ...

class UsbRequest(java.lang.Object):
    def __init__(self) -> None: ...
    def cancel(self) -> bool: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getClientData(self) -> java.lang.Object: ...
    def getEndpoint(self) -> UsbEndpoint: ...
    def initialize(self, connection: UsbDeviceConnection, endpoint: UsbEndpoint, /) -> bool: ...
    @typing.overload
    def queue(self, buffer: java.nio.ByteBuffer, /) -> bool: ...
    @typing.overload
    def queue(self, buffer: java.nio.ByteBuffer, length: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setClientData(self, data: java.lang.Object | int | bool | float | str, /) -> None: ...



import typing

import android.app
import android.bluetooth
import android.content
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.util
import java.util.concurrent

class MidiDevice(java.io.Closeable):
    def close(self) -> None: ...
    def connectPorts(self, inputPort: MidiInputPort, outputPortNumber: int | java.jint | java.lang.Integer, /) -> MidiDevice.MidiConnection: ...
    def finalize(self) -> None: ...
    def getInfo(self) -> MidiDeviceInfo: ...
    def openInputPort(self, portNumber: int | java.jint | java.lang.Integer, /) -> MidiInputPort: ...
    def openOutputPort(self, portNumber: int | java.jint | java.lang.Integer, /) -> MidiOutputPort: ...
    def toString(self) -> str: ...

    class MidiConnection(java.io.Closeable):
        def close(self) -> None: ...
        def finalize(self) -> None: ...

class MidiDeviceInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MidiDeviceInfo]] = ...
    PROPERTY_BLUETOOTH_DEVICE: typing.ClassVar[str] = ...
    PROPERTY_MANUFACTURER: typing.ClassVar[str] = ...
    PROPERTY_NAME: typing.ClassVar[str] = ...
    PROPERTY_PRODUCT: typing.ClassVar[str] = ...
    PROPERTY_SERIAL_NUMBER: typing.ClassVar[str] = ...
    PROPERTY_USB_DEVICE: typing.ClassVar[str] = ...
    PROPERTY_VERSION: typing.ClassVar[str] = ...
    PROTOCOL_UMP_MIDI_1_0_UP_TO_128_BITS: typing.ClassVar[int] = ...
    PROTOCOL_UMP_MIDI_1_0_UP_TO_128_BITS_AND_JRTS: typing.ClassVar[int] = ...
    PROTOCOL_UMP_MIDI_1_0_UP_TO_64_BITS: typing.ClassVar[int] = ...
    PROTOCOL_UMP_MIDI_1_0_UP_TO_64_BITS_AND_JRTS: typing.ClassVar[int] = ...
    PROTOCOL_UMP_MIDI_2_0: typing.ClassVar[int] = ...
    PROTOCOL_UMP_MIDI_2_0_AND_JRTS: typing.ClassVar[int] = ...
    PROTOCOL_UMP_USE_MIDI_CI: typing.ClassVar[int] = ...
    PROTOCOL_UNKNOWN: typing.ClassVar[int] = ...
    TYPE_BLUETOOTH: typing.ClassVar[int] = ...
    TYPE_USB: typing.ClassVar[int] = ...
    TYPE_VIRTUAL: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDefaultProtocol(self) -> int: ...
    def getId(self) -> int: ...
    def getInputPortCount(self) -> int: ...
    def getOutputPortCount(self) -> int: ...
    def getPorts(self) -> java.chaquopy.JavaArray[MidiDeviceInfo.PortInfo]: ...
    def getProperties(self) -> android.os.Bundle: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isPrivate(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class PortInfo(java.lang.Object):
        TYPE_INPUT: typing.ClassVar[int] = ...
        TYPE_OUTPUT: typing.ClassVar[int] = ...
        def getName(self) -> str: ...
        def getPortNumber(self) -> int: ...
        def getType(self) -> int: ...

class MidiDeviceService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def getDeviceInfo(self) -> MidiDeviceInfo: ...
    def getOutputPortReceivers(self) -> java.chaquopy.JavaArray[MidiReceiver]: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onClose(self) -> None: ...
    def onCreate(self) -> None: ...
    def onDeviceStatusChanged(self, status: MidiDeviceStatus, /) -> None: ...
    def onGetInputPortReceivers(self) -> java.chaquopy.JavaArray[MidiReceiver]: ...

class MidiDeviceStatus(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MidiDeviceStatus]] = ...
    def describeContents(self) -> int: ...
    def getDeviceInfo(self) -> MidiDeviceInfo: ...
    def getOutputPortOpenCount(self, portNumber: int | java.jint | java.lang.Integer, /) -> int: ...
    def isInputPortOpen(self, portNumber: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class MidiInputPort(MidiReceiver, java.io.Closeable):
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getPortNumber(self) -> int: ...
    def onFlush(self) -> None: ...
    def onSend(self, msg: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, timestamp: int | java.jlong | java.lang.Long, /) -> None: ...

class MidiManager(java.lang.Object):
    TRANSPORT_MIDI_BYTE_STREAM: typing.ClassVar[int] = ...
    TRANSPORT_UNIVERSAL_MIDI_PACKETS: typing.ClassVar[int] = ...
    def getDevices(self) -> java.chaquopy.JavaArray[MidiDeviceInfo]: ...
    def getDevicesForTransport(self, transport: int | java.jint | java.lang.Integer, /) -> java.util.Set[MidiDeviceInfo]: ...
    def openBluetoothDevice(self, bluetoothDevice: android.bluetooth.BluetoothDevice, listener: MidiManager.OnDeviceOpenedListener, handler: android.os.Handler, /) -> None: ...
    def openDevice(self, deviceInfo: MidiDeviceInfo, listener: MidiManager.OnDeviceOpenedListener, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def registerDeviceCallback(self, callback: MidiManager.DeviceCallback, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def registerDeviceCallback(self, transport: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: MidiManager.DeviceCallback, /) -> None: ...
    def unregisterDeviceCallback(self, callback: MidiManager.DeviceCallback, /) -> None: ...

    class OnDeviceOpenedListener(java.lang.Object):
        def onDeviceOpened(self, arg1: MidiDevice, /) -> None: ...

    class DeviceCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onDeviceAdded(self, device: MidiDeviceInfo, /) -> None: ...
        def onDeviceRemoved(self, device: MidiDeviceInfo, /) -> None: ...
        def onDeviceStatusChanged(self, status: MidiDeviceStatus, /) -> None: ...

class MidiOutputPort(MidiSender, java.io.Closeable):
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getPortNumber(self) -> int: ...
    def onConnect(self, receiver: MidiReceiver, /) -> None: ...
    def onDisconnect(self, receiver: MidiReceiver, /) -> None: ...

class MidiReceiver(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, maxMessageSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def flush(self) -> None: ...
    def getMaxMessageSize(self) -> int: ...
    def onFlush(self) -> None: ...
    def onSend(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def send(self, msg: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def send(self, msg: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, timestamp: int | java.jlong | java.lang.Long, /) -> None: ...

class MidiSender(java.lang.Object):
    def __init__(self) -> None: ...
    def connect(self, receiver: MidiReceiver, /) -> None: ...
    def disconnect(self, receiver: MidiReceiver, /) -> None: ...
    def onConnect(self, arg1: MidiReceiver, /) -> None: ...
    def onDisconnect(self, arg1: MidiReceiver, /) -> None: ...

class MidiUmpDeviceService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def getDeviceInfo(self) -> MidiDeviceInfo | None: ...
    def getOutputPortReceivers(self) -> java.util.List[MidiReceiver]: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder | None: ...
    def onClose(self) -> None: ...
    def onCreate(self) -> None: ...
    def onDeviceStatusChanged(self, status: MidiDeviceStatus, /) -> None: ...
    def onGetInputPortReceivers(self) -> java.util.List[MidiReceiver]: ...



import typing

import android.os
import java.lang
import java.util
import java.util.concurrent

class DeviceId(java.lang.Object):
    DEVICE_ID_TYPE_IMEI: typing.ClassVar[int] = ...
    DEVICE_ID_TYPE_MEID: typing.ClassVar[int] = ...
    def getId(self) -> str: ...
    def getType(self) -> int: ...

class DeviceLockManager(java.lang.Object):
    DEVICE_LOCK_ROLE_FINANCING: typing.ClassVar[int] = ...
    def getDeviceId(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[DeviceId, java.lang.Exception], /) -> None: ...
    def getKioskApps(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.Map[java.lang.Integer, java.lang.String], java.lang.Exception], /) -> None: ...
    def isDeviceLocked(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Boolean, java.lang.Exception], /) -> None: ...
    def lockDevice(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, java.lang.Exception], /) -> None: ...
    def unlockDevice(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, java.lang.Exception], /) -> None: ...



import typing

import android.app
import android.content
import android.os
import java
import java.lang

class DownloadableSubscription(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DownloadableSubscription]] = ...
    def describeContents(self) -> int: ...
    @staticmethod
    def forActivationCode(encodedActivationCode: str | java.lang.String, /) -> DownloadableSubscription: ...
    def getConfirmationCode(self) -> str | None: ...
    def getEncodedActivationCode(self) -> str | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, baseSubscription: DownloadableSubscription, /) -> None: ...
        @typing.overload
        def __init__(self, encodedActivationCode: str | java.lang.String, /) -> None: ...
        def build(self) -> DownloadableSubscription: ...
        def setConfirmationCode(self, value: str | java.lang.String, /) -> DownloadableSubscription.Builder: ...
        def setEncodedActivationCode(self, value: str | java.lang.String, /) -> DownloadableSubscription.Builder: ...

class EuiccInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[EuiccInfo]] = ...
    def __init__(self, osVersion: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getOsVersion(self) -> str | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class EuiccManager(java.lang.Object):
    ACTION_MANAGE_EMBEDDED_SUBSCRIPTIONS: typing.ClassVar[str] = ...
    ACTION_NOTIFY_CARRIER_SETUP_INCOMPLETE: typing.ClassVar[str] = ...
    ACTION_START_EUICC_ACTIVATION: typing.ClassVar[str] = ...
    EMBEDDED_SUBSCRIPTION_RESULT_ERROR: typing.ClassVar[int] = ...
    EMBEDDED_SUBSCRIPTION_RESULT_OK: typing.ClassVar[int] = ...
    EMBEDDED_SUBSCRIPTION_RESULT_RESOLVABLE_ERROR: typing.ClassVar[int] = ...
    ERROR_ADDRESS_MISSING: typing.ClassVar[int] = ...
    ERROR_CARRIER_LOCKED: typing.ClassVar[int] = ...
    ERROR_CERTIFICATE_ERROR: typing.ClassVar[int] = ...
    ERROR_CONNECTION_ERROR: typing.ClassVar[int] = ...
    ERROR_DISALLOWED_BY_PPR: typing.ClassVar[int] = ...
    ERROR_EUICC_INSUFFICIENT_MEMORY: typing.ClassVar[int] = ...
    ERROR_EUICC_MISSING: typing.ClassVar[int] = ...
    ERROR_INCOMPATIBLE_CARRIER: typing.ClassVar[int] = ...
    ERROR_INSTALL_PROFILE: typing.ClassVar[int] = ...
    ERROR_INVALID_ACTIVATION_CODE: typing.ClassVar[int] = ...
    ERROR_INVALID_CONFIRMATION_CODE: typing.ClassVar[int] = ...
    ERROR_INVALID_PORT: typing.ClassVar[int] = ...
    ERROR_INVALID_RESPONSE: typing.ClassVar[int] = ...
    ERROR_NO_PROFILES_AVAILABLE: typing.ClassVar[int] = ...
    ERROR_OPERATION_BUSY: typing.ClassVar[int] = ...
    ERROR_SIM_MISSING: typing.ClassVar[int] = ...
    ERROR_TIME_OUT: typing.ClassVar[int] = ...
    ERROR_UNSUPPORTED_VERSION: typing.ClassVar[int] = ...
    EUICC_MEMORY_FIELD_UNAVAILABLE: typing.ClassVar[int] = ...
    EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE: typing.ClassVar[str] = ...
    EXTRA_EMBEDDED_SUBSCRIPTION_DOWNLOADABLE_SUBSCRIPTION: typing.ClassVar[str] = ...
    EXTRA_EMBEDDED_SUBSCRIPTION_ERROR_CODE: typing.ClassVar[str] = ...
    EXTRA_EMBEDDED_SUBSCRIPTION_OPERATION_CODE: typing.ClassVar[str] = ...
    EXTRA_EMBEDDED_SUBSCRIPTION_SMDX_REASON_CODE: typing.ClassVar[str] = ...
    EXTRA_EMBEDDED_SUBSCRIPTION_SMDX_SUBJECT_CODE: typing.ClassVar[str] = ...
    EXTRA_USE_QR_SCANNER: typing.ClassVar[str] = ...
    META_DATA_CARRIER_ICON: typing.ClassVar[str] = ...
    OPERATION_APDU: typing.ClassVar[int] = ...
    OPERATION_DOWNLOAD: typing.ClassVar[int] = ...
    OPERATION_EUICC_CARD: typing.ClassVar[int] = ...
    OPERATION_EUICC_GSMA: typing.ClassVar[int] = ...
    OPERATION_HTTP: typing.ClassVar[int] = ...
    OPERATION_METADATA: typing.ClassVar[int] = ...
    OPERATION_SIM_SLOT: typing.ClassVar[int] = ...
    OPERATION_SMDX: typing.ClassVar[int] = ...
    OPERATION_SMDX_SUBJECT_REASON_CODE: typing.ClassVar[int] = ...
    OPERATION_SWITCH: typing.ClassVar[int] = ...
    OPERATION_SYSTEM: typing.ClassVar[int] = ...
    def createForCardId(self, cardId: int | java.jint | java.lang.Integer, /) -> EuiccManager: ...
    def deleteSubscription(self, subscriptionId: int | java.jint | java.lang.Integer, callbackIntent: android.app.PendingIntent, /) -> None: ...
    def downloadSubscription(self, subscription: DownloadableSubscription, switchAfterDownload: bool | java.jboolean | java.lang.Boolean, callbackIntent: android.app.PendingIntent, /) -> None: ...
    def getAvailableMemoryInBytes(self) -> int: ...
    def getEid(self) -> str | None: ...
    def getEuiccInfo(self) -> EuiccInfo | None: ...
    def isEnabled(self) -> bool: ...
    def isSimPortAvailable(self, portIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def startResolutionActivity(self, activity: android.app.Activity, requestCode: int | java.jint | java.lang.Integer, resultIntent: android.content.Intent, callbackIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def switchToSubscription(self, subscriptionId: int | java.jint | java.lang.Integer, callbackIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def switchToSubscription(self, subscriptionId: int | java.jint | java.lang.Integer, portIndex: int | java.jint | java.lang.Integer, callbackIntent: android.app.PendingIntent, /) -> None: ...
    def updateSubscriptionNickname(self, subscriptionId: int | java.jint | java.lang.Integer, nickname: str | java.lang.String, callbackIntent: android.app.PendingIntent, /) -> None: ...



import typing

import android.app
import android.app.assist
import android.app.slice
import android.content
import android.icu.text
import android.os
import android.service.assist.classification
import android.view.autofill
import android.view.inputmethod
import android.widget
import android.widget.inline
import java
import java.chaquopy
import java.lang
import java.util
import java.util.regex

class AutofillService(android.app.Service):
    EXTRA_FILL_RESPONSE: typing.ClassVar[str] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def getFillEventHistory(self) -> FillEventHistory | None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onConnected(self) -> None: ...
    def onCreate(self) -> None: ...
    def onDisconnected(self) -> None: ...
    def onFillRequest(self, arg1: FillRequest, arg2: android.os.CancellationSignal, arg3: FillCallback, /) -> None: ...
    def onSaveRequest(self, arg1: SaveRequest, arg2: SaveCallback, /) -> None: ...
    def onSavedDatasetsInfoRequest(self, callback: SavedDatasetsInfoCallback, /) -> None: ...
    def onSessionDestroyed(self, history: FillEventHistory, /) -> None: ...

class BatchUpdates(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BatchUpdates]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> BatchUpdates: ...
        def transformChild(self, id: int | java.jint | java.lang.Integer, transformation: Transformation, /) -> BatchUpdates.Builder: ...
        def updateTemplate(self, updates: android.widget.RemoteViews, /) -> BatchUpdates.Builder: ...

class CharSequenceTransformation(Transformation, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CharSequenceTransformation]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, id: android.view.autofill.AutofillId, regex: java.util.regex.Pattern, subst: str | java.lang.String, /) -> None: ...
        def addField(self, id: android.view.autofill.AutofillId, regex: java.util.regex.Pattern, subst: str | java.lang.String, /) -> CharSequenceTransformation.Builder: ...
        def build(self) -> CharSequenceTransformation: ...

class CustomDescription(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CustomDescription]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, parentPresentation: android.widget.RemoteViews, /) -> None: ...
        def addChild(self, id: int | java.jint | java.lang.Integer, transformation: Transformation, /) -> CustomDescription.Builder: ...
        def addOnClickAction(self, id: int | java.jint | java.lang.Integer, action: OnClickAction, /) -> CustomDescription.Builder: ...
        def batchUpdate(self, condition: Validator, updates: BatchUpdates, /) -> CustomDescription.Builder: ...
        def build(self) -> CustomDescription: ...

class Dataset(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Dataset]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, presentations: Presentations, /) -> None: ...
        @typing.overload
        def __init__(self, presentation: android.widget.RemoteViews, /) -> None: ...
        def build(self) -> Dataset: ...
        def setAuthentication(self, authentication: android.content.IntentSender, /) -> Dataset.Builder: ...
        @typing.overload
        def setField(self, id: android.view.autofill.AutofillId, field: Field, /) -> Dataset.Builder: ...
        @typing.overload
        def setField(self, hint: str | java.lang.String, field: Field, /) -> Dataset.Builder: ...
        def setFieldForAllHints(self, field: Field, /) -> Dataset.Builder: ...
        def setId(self, id: str | java.lang.String, /) -> Dataset.Builder: ...
        @typing.overload
        def setInlinePresentation(self, inlinePresentation: InlinePresentation, /) -> Dataset.Builder: ...
        @typing.overload
        def setInlinePresentation(self, inlinePresentation: InlinePresentation, inlineTooltipPresentation: InlinePresentation, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, presentation: android.widget.RemoteViews, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, filter: java.util.regex.Pattern, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, presentation: android.widget.RemoteViews, inlinePresentation: InlinePresentation, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, filter: java.util.regex.Pattern, presentation: android.widget.RemoteViews, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, presentation: android.widget.RemoteViews, inlinePresentation: InlinePresentation, inlineTooltipPresentation: InlinePresentation, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, filter: java.util.regex.Pattern, presentation: android.widget.RemoteViews, inlinePresentation: InlinePresentation, /) -> Dataset.Builder: ...
        @typing.overload
        def setValue(self, id: android.view.autofill.AutofillId, value: android.view.autofill.AutofillValue, filter: java.util.regex.Pattern, presentation: android.widget.RemoteViews, inlinePresentation: InlinePresentation, inlineTooltipPresentation: InlinePresentation, /) -> Dataset.Builder: ...

class DateTransformation(Transformation, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DateTransformation]] = ...
    def __init__(self, id: android.view.autofill.AutofillId, dateFormat: android.icu.text.DateFormat, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DateValueSanitizer(Sanitizer, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DateValueSanitizer]] = ...
    def __init__(self, dateFormat: android.icu.text.DateFormat, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Field(java.lang.Object):
    def getFilter(self) -> java.util.regex.Pattern | None: ...
    def getPresentations(self) -> Presentations | None: ...
    def getValue(self) -> android.view.autofill.AutofillValue | None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> Field: ...
        def setFilter(self, value: java.util.regex.Pattern, /) -> Field.Builder: ...
        def setPresentations(self, value: Presentations, /) -> Field.Builder: ...
        def setValue(self, value: android.view.autofill.AutofillValue, /) -> Field.Builder: ...

class FieldClassification(java.lang.Object):
    def getMatches(self) -> java.util.List[FieldClassification.Match]: ...
    def toString(self) -> str: ...

    class Match(java.lang.Object):
        def getCategoryId(self) -> str: ...
        def getScore(self) -> float: ...
        def toString(self) -> str: ...

class FillCallback(java.lang.Object):
    def onFailure(self, message: java.lang.CharSequence, /) -> None: ...
    def onSuccess(self, response: FillResponse, /) -> None: ...

class FillContext(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FillContext]] = ...
    def describeContents(self) -> int: ...
    def getFocusedId(self) -> android.view.autofill.AutofillId: ...
    def getRequestId(self) -> int: ...
    def getStructure(self) -> android.app.assist.AssistStructure: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FillEventHistory(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FillEventHistory]] = ...
    def describeContents(self) -> int: ...
    def getClientState(self) -> android.os.Bundle | None: ...
    def getEvents(self) -> java.util.List[FillEventHistory.Event] | None: ...
    def getSessionId(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Event(java.lang.Object):
        NO_SAVE_UI_REASON_DATASET_MATCH: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_FIELD_VALIDATION_FAILED: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_HAS_EMPTY_REQUIRED: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_NONE: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_NO_SAVE_INFO: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_NO_VALUE_CHANGED: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_USING_CREDMAN: typing.ClassVar[int] = ...
        NO_SAVE_UI_REASON_WITH_DELAY_SAVE_FLAG: typing.ClassVar[int] = ...
        TYPE_AUTHENTICATION_SELECTED: typing.ClassVar[int] = ...
        TYPE_CONTEXT_COMMITTED: typing.ClassVar[int] = ...
        TYPE_DATASETS_SHOWN: typing.ClassVar[int] = ...
        TYPE_DATASET_AUTHENTICATION_SELECTED: typing.ClassVar[int] = ...
        TYPE_DATASET_SELECTED: typing.ClassVar[int] = ...
        TYPE_SAVE_SHOWN: typing.ClassVar[int] = ...
        TYPE_VIEW_REQUESTED_AUTOFILL: typing.ClassVar[int] = ...
        UI_TYPE_CREDENTIAL_MANAGER: typing.ClassVar[int] = ...
        UI_TYPE_DIALOG: typing.ClassVar[int] = ...
        UI_TYPE_INLINE: typing.ClassVar[int] = ...
        UI_TYPE_MENU: typing.ClassVar[int] = ...
        UI_TYPE_UNKNOWN: typing.ClassVar[int] = ...
        def getChangedFields(self) -> java.util.Map[android.view.autofill.AutofillId, java.lang.String]: ...
        def getClientState(self) -> android.os.Bundle: ...
        def getDatasetId(self) -> str: ...
        def getFieldsClassification(self) -> java.util.Map[android.view.autofill.AutofillId, FieldClassification]: ...
        def getFocusedId(self) -> android.view.autofill.AutofillId: ...
        def getIgnoredDatasetIds(self) -> java.util.Set[java.lang.String]: ...
        def getManuallyEnteredField(self) -> java.util.Map[android.view.autofill.AutofillId, java.util.Set[java.lang.String]]: ...
        def getNoSaveUiReason(self) -> int: ...
        def getSelectedDatasetIds(self) -> java.util.Set[java.lang.String]: ...
        def getShownDatasetIds(self) -> java.util.Set[java.lang.String]: ...
        def getType(self) -> int: ...
        def getUiType(self) -> int: ...
        def toString(self) -> str: ...

class FillRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FillRequest]] = ...
    FLAG_COMPATIBILITY_MODE_REQUEST: typing.ClassVar[int] = ...
    FLAG_MANUAL_REQUEST: typing.ClassVar[int] = ...
    FLAG_SUPPORTS_FILL_DIALOG: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getClientState(self) -> android.os.Bundle | None: ...
    def getDelayedFillIntentSender(self) -> android.content.IntentSender | None: ...
    def getFillContexts(self) -> java.util.List[FillContext]: ...
    def getFlags(self) -> int: ...
    def getHints(self) -> java.util.List[java.lang.String]: ...
    def getId(self) -> int: ...
    def getInlineSuggestionsRequest(self) -> android.view.inputmethod.InlineSuggestionsRequest | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FillResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FillResponse]] = ...
    FLAG_DELAY_FILL: typing.ClassVar[int] = ...
    FLAG_DISABLE_ACTIVITY_ONLY: typing.ClassVar[int] = ...
    FLAG_TRACK_CONTEXT_COMMITED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addDataset(self, dataset: Dataset, /) -> FillResponse.Builder: ...
        def build(self) -> FillResponse: ...
        def disableAutofill(self, duration: int | java.jlong | java.lang.Long, /) -> FillResponse.Builder: ...
        @typing.overload
        def setAuthentication(self, ids: java.chaquopy.JavaArray[android.view.autofill.AutofillId], authentication: android.content.IntentSender, presentations: Presentations, /) -> FillResponse.Builder: ...
        @typing.overload
        def setAuthentication(self, ids: java.chaquopy.JavaArray[android.view.autofill.AutofillId], authentication: android.content.IntentSender, presentation: android.widget.RemoteViews, /) -> FillResponse.Builder: ...
        @typing.overload
        def setAuthentication(self, ids: java.chaquopy.JavaArray[android.view.autofill.AutofillId], authentication: android.content.IntentSender, presentation: android.widget.RemoteViews, inlinePresentation: InlinePresentation, /) -> FillResponse.Builder: ...
        @typing.overload
        def setAuthentication(self, ids: java.chaquopy.JavaArray[android.view.autofill.AutofillId], authentication: android.content.IntentSender, presentation: android.widget.RemoteViews, inlinePresentation: InlinePresentation, inlineTooltipPresentation: InlinePresentation, /) -> FillResponse.Builder: ...
        def setClientState(self, clientState: android.os.Bundle, /) -> FillResponse.Builder: ...
        def setDetectedFieldClassifications(self, fieldInfos: java.util.Set[android.service.assist.classification.FieldClassification], /) -> FillResponse.Builder: ...
        def setDialogHeader(self, header: android.widget.RemoteViews, /) -> FillResponse.Builder: ...
        def setFieldClassificationIds(self, *ids: android.view.autofill.AutofillId) -> FillResponse.Builder: ...
        def setFillDialogTriggerIds(self, *ids: android.view.autofill.AutofillId) -> FillResponse.Builder: ...
        def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> FillResponse.Builder: ...
        def setFooter(self, footer: android.widget.RemoteViews, /) -> FillResponse.Builder: ...
        def setHeader(self, header: android.widget.RemoteViews, /) -> FillResponse.Builder: ...
        def setIconResourceId(self, id: int | java.jint | java.lang.Integer, /) -> FillResponse.Builder: ...
        def setIgnoredIds(self, *ids: android.view.autofill.AutofillId) -> FillResponse.Builder: ...
        def setPresentationCancelIds(self, ids: java.chaquopy.JavaArrayJInt, /) -> FillResponse.Builder: ...
        def setSaveInfo(self, saveInfo: SaveInfo, /) -> FillResponse.Builder: ...
        def setServiceDisplayNameResourceId(self, id: int | java.jint | java.lang.Integer, /) -> FillResponse.Builder: ...
        def setShowFillDialogIcon(self, show: bool | java.jboolean | java.lang.Boolean, /) -> FillResponse.Builder: ...
        def setShowSaveDialogIcon(self, show: bool | java.jboolean | java.lang.Boolean, /) -> FillResponse.Builder: ...
        def setUserData(self, userData: UserData, /) -> FillResponse.Builder: ...

class ImageTransformation(Transformation, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ImageTransformation]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, id: android.view.autofill.AutofillId, regex: java.util.regex.Pattern, resId: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, id: android.view.autofill.AutofillId, regex: java.util.regex.Pattern, resId: int | java.jint | java.lang.Integer, contentDescription: java.lang.CharSequence, /) -> None: ...
        @typing.overload
        def addOption(self, regex: java.util.regex.Pattern, resId: int | java.jint | java.lang.Integer, /) -> ImageTransformation.Builder: ...
        @typing.overload
        def addOption(self, regex: java.util.regex.Pattern, resId: int | java.jint | java.lang.Integer, contentDescription: java.lang.CharSequence, /) -> ImageTransformation.Builder: ...
        def build(self) -> ImageTransformation: ...

class InlinePresentation(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InlinePresentation]] = ...
    def __init__(self, slice: android.app.slice.Slice, inlinePresentationSpec: android.widget.inline.InlinePresentationSpec, pinned: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def createTooltipPresentation(slice: android.app.slice.Slice, spec: android.widget.inline.InlinePresentationSpec, /) -> InlinePresentation: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInlinePresentationSpec(self) -> android.widget.inline.InlinePresentationSpec: ...
    def getSlice(self) -> android.app.slice.Slice: ...
    def hashCode(self) -> int: ...
    def isPinned(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LuhnChecksumValidator(Validator, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LuhnChecksumValidator]] = ...
    def __init__(self, *ids: android.view.autofill.AutofillId) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class OnClickAction(java.lang.Object): ...

class Presentations(java.lang.Object):
    def getDialogPresentation(self) -> android.widget.RemoteViews | None: ...
    def getInlinePresentation(self) -> InlinePresentation | None: ...
    def getInlineTooltipPresentation(self) -> InlinePresentation | None: ...
    def getMenuPresentation(self) -> android.widget.RemoteViews | None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> Presentations: ...
        def setDialogPresentation(self, value: android.widget.RemoteViews, /) -> Presentations.Builder: ...
        def setInlinePresentation(self, value: InlinePresentation, /) -> Presentations.Builder: ...
        def setInlineTooltipPresentation(self, value: InlinePresentation, /) -> Presentations.Builder: ...
        def setMenuPresentation(self, value: android.widget.RemoteViews, /) -> Presentations.Builder: ...

class RegexValidator(Validator, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RegexValidator]] = ...
    def __init__(self, id: android.view.autofill.AutofillId, regex: java.util.regex.Pattern, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Sanitizer(java.lang.Object): ...

class SaveCallback(java.lang.Object):
    def onFailure(self, message: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def onSuccess(self) -> None: ...
    @typing.overload
    def onSuccess(self, intentSender: android.content.IntentSender, /) -> None: ...

class SaveInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SaveInfo]] = ...
    FLAG_DELAY_SAVE: typing.ClassVar[int] = ...
    FLAG_DONT_SAVE_ON_FINISH: typing.ClassVar[int] = ...
    FLAG_SAVE_ON_ALL_VIEWS_INVISIBLE: typing.ClassVar[int] = ...
    NEGATIVE_BUTTON_STYLE_CANCEL: typing.ClassVar[int] = ...
    NEGATIVE_BUTTON_STYLE_NEVER: typing.ClassVar[int] = ...
    NEGATIVE_BUTTON_STYLE_REJECT: typing.ClassVar[int] = ...
    POSITIVE_BUTTON_STYLE_CONTINUE: typing.ClassVar[int] = ...
    POSITIVE_BUTTON_STYLE_SAVE: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_ADDRESS: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_CREDIT_CARD: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_DEBIT_CARD: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_EMAIL_ADDRESS: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_GENERIC: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_GENERIC_CARD: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_PASSWORD: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_PAYMENT_CARD: typing.ClassVar[int] = ...
    SAVE_DATA_TYPE_USERNAME: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, type: int | java.jint | java.lang.Integer, requiredIds: java.chaquopy.JavaArray[android.view.autofill.AutofillId], /) -> None: ...
        def addSanitizer(self, sanitizer: Sanitizer, /, *ids: android.view.autofill.AutofillId) -> SaveInfo.Builder: ...
        def build(self) -> SaveInfo: ...
        def setCustomDescription(self, customDescription: CustomDescription, /) -> SaveInfo.Builder: ...
        def setDescription(self, description: java.lang.CharSequence, /) -> SaveInfo.Builder: ...
        def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> SaveInfo.Builder: ...
        def setNegativeAction(self, style: int | java.jint | java.lang.Integer, listener: android.content.IntentSender, /) -> SaveInfo.Builder: ...
        def setOptionalIds(self, ids: java.chaquopy.JavaArray[android.view.autofill.AutofillId], /) -> SaveInfo.Builder: ...
        def setPositiveAction(self, style: int | java.jint | java.lang.Integer, /) -> SaveInfo.Builder: ...
        def setTriggerId(self, id: android.view.autofill.AutofillId, /) -> SaveInfo.Builder: ...
        def setValidator(self, validator: Validator, /) -> SaveInfo.Builder: ...

class SaveRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SaveRequest]] = ...
    def describeContents(self) -> int: ...
    def getClientState(self) -> android.os.Bundle | None: ...
    def getDatasetIds(self) -> java.util.List[java.lang.String] | None: ...
    def getFillContexts(self) -> java.util.List[FillContext]: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SavedDatasetsInfo(java.lang.Object):
    TYPE_OTHER: typing.ClassVar[str] = ...
    TYPE_PASSWORDS: typing.ClassVar[str] = ...
    def __init__(self, type: str | java.lang.String, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCount(self) -> int: ...
    def getType(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class SavedDatasetsInfoCallback(java.lang.Object):
    ERROR_NEEDS_USER_ACTION: typing.ClassVar[int] = ...
    ERROR_OTHER: typing.ClassVar[int] = ...
    ERROR_UNSUPPORTED: typing.ClassVar[int] = ...
    def onError(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSuccess(self, arg1: java.util.Set[SavedDatasetsInfo], /) -> None: ...

class TextValueSanitizer(Sanitizer, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TextValueSanitizer]] = ...
    def __init__(self, regex: java.util.regex.Pattern, subst: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Transformation(java.lang.Object): ...

class UserData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UserData]] = ...
    def describeContents(self) -> int: ...
    def getFieldClassificationAlgorithm(self) -> str | None: ...
    def getFieldClassificationAlgorithmForCategory(self, categoryId: str | java.lang.String, /) -> str | None: ...
    def getId(self) -> str: ...
    @staticmethod
    def getMaxCategoryCount() -> int: ...
    @staticmethod
    def getMaxFieldClassificationIdsSize() -> int: ...
    @staticmethod
    def getMaxUserDataSize() -> int: ...
    @staticmethod
    def getMaxValueLength() -> int: ...
    @staticmethod
    def getMinValueLength() -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, id: str | java.lang.String, value: str | java.lang.String, categoryId: str | java.lang.String, /) -> None: ...
        def add(self, value: str | java.lang.String, categoryId: str | java.lang.String, /) -> UserData.Builder: ...
        def build(self) -> UserData: ...
        def setFieldClassificationAlgorithm(self, name: str | java.lang.String, args: android.os.Bundle, /) -> UserData.Builder: ...
        def setFieldClassificationAlgorithmForCategory(self, categoryId: str | java.lang.String, name: str | java.lang.String, args: android.os.Bundle, /) -> UserData.Builder: ...

class Validator(java.lang.Object): ...

class Validators(java.lang.Object):
    @staticmethod
    def and_(*validators: Validator) -> Validator: ...
    @staticmethod
    def not_(validator: Validator, /) -> Validator: ...
    @staticmethod
    def or_(*validators: Validator) -> Validator: ...

class VisibilitySetterAction(OnClickAction, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VisibilitySetterAction]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, id: int | java.jint | java.lang.Integer, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> VisibilitySetterAction: ...
        def setVisibility(self, id: int | java.jint | java.lang.Integer, visibility: int | java.jint | java.lang.Integer, /) -> VisibilitySetterAction.Builder: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import java.security
import java.time
import java.util
import java.util.concurrent

class AclEntry(java.lang.Object):
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flags(self) -> java.util.Set[AclEntryFlag]: ...
    def hashCode(self) -> int: ...
    @typing.overload
    @staticmethod
    def newBuilder() -> AclEntry.Builder: ...
    @typing.overload
    @staticmethod
    def newBuilder(entry: AclEntry, /) -> AclEntry.Builder: ...
    def permissions(self) -> java.util.Set[AclEntryPermission]: ...
    def principal(self) -> UserPrincipal: ...
    def toString(self) -> str: ...
    def type(self) -> AclEntryType: ...

    class Builder(java.lang.Object):
        def build(self) -> AclEntry: ...
        @typing.overload
        def setFlags(self, flags: java.util.Set[AclEntryFlag], /) -> AclEntry.Builder: ...
        @typing.overload
        def setFlags(self, *flags: AclEntryFlag) -> AclEntry.Builder: ...
        @typing.overload
        def setPermissions(self, perms: java.util.Set[AclEntryPermission], /) -> AclEntry.Builder: ...
        @typing.overload
        def setPermissions(self, *perms: AclEntryPermission) -> AclEntry.Builder: ...
        def setPrincipal(self, who: UserPrincipal, /) -> AclEntry.Builder: ...
        def setType(self, type: AclEntryType, /) -> AclEntry.Builder: ...

class AclEntryFlag(java.lang.Enum[AclEntryFlag]):
    DIRECTORY_INHERIT: typing.ClassVar[AclEntryFlag] = ...
    FILE_INHERIT: typing.ClassVar[AclEntryFlag] = ...
    INHERIT_ONLY: typing.ClassVar[AclEntryFlag] = ...
    NO_PROPAGATE_INHERIT: typing.ClassVar[AclEntryFlag] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> AclEntryFlag: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[AclEntryFlag]: ...

class AclEntryPermission(java.lang.Enum[AclEntryPermission]):
    ADD_FILE: typing.ClassVar[AclEntryPermission] = ...
    ADD_SUBDIRECTORY: typing.ClassVar[AclEntryPermission] = ...
    APPEND_DATA: typing.ClassVar[AclEntryPermission] = ...
    DELETE: typing.ClassVar[AclEntryPermission] = ...
    DELETE_CHILD: typing.ClassVar[AclEntryPermission] = ...
    EXECUTE: typing.ClassVar[AclEntryPermission] = ...
    LIST_DIRECTORY: typing.ClassVar[AclEntryPermission] = ...
    READ_ACL: typing.ClassVar[AclEntryPermission] = ...
    READ_ATTRIBUTES: typing.ClassVar[AclEntryPermission] = ...
    READ_DATA: typing.ClassVar[AclEntryPermission] = ...
    READ_NAMED_ATTRS: typing.ClassVar[AclEntryPermission] = ...
    SYNCHRONIZE: typing.ClassVar[AclEntryPermission] = ...
    WRITE_ACL: typing.ClassVar[AclEntryPermission] = ...
    WRITE_ATTRIBUTES: typing.ClassVar[AclEntryPermission] = ...
    WRITE_DATA: typing.ClassVar[AclEntryPermission] = ...
    WRITE_NAMED_ATTRS: typing.ClassVar[AclEntryPermission] = ...
    WRITE_OWNER: typing.ClassVar[AclEntryPermission] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> AclEntryPermission: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[AclEntryPermission]: ...

class AclEntryType(java.lang.Enum[AclEntryType]):
    ALARM: typing.ClassVar[AclEntryType] = ...
    ALLOW: typing.ClassVar[AclEntryType] = ...
    AUDIT: typing.ClassVar[AclEntryType] = ...
    DENY: typing.ClassVar[AclEntryType] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> AclEntryType: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[AclEntryType]: ...

class AclFileAttributeView(FileOwnerAttributeView):
    def getAcl(self) -> java.util.List[AclEntry]: ...
    def name(self) -> str: ...
    def setAcl(self, arg1: java.util.List[AclEntry], /) -> None: ...

class AttributeView(java.lang.Object):
    def name(self) -> str: ...

class BasicFileAttributeView(FileAttributeView):
    def name(self) -> str: ...
    def readAttributes(self) -> BasicFileAttributes: ...
    def setTimes(self, arg1: FileTime, arg2: FileTime, arg3: FileTime, /) -> None: ...

class BasicFileAttributes(java.lang.Object):
    def creationTime(self) -> FileTime: ...
    def fileKey(self) -> java.lang.Object: ...
    def isDirectory(self) -> bool: ...
    def isOther(self) -> bool: ...
    def isRegularFile(self) -> bool: ...
    def isSymbolicLink(self) -> bool: ...
    def lastAccessTime(self) -> FileTime: ...
    def lastModifiedTime(self) -> FileTime: ...
    def size(self) -> int: ...

class DosFileAttributeView(BasicFileAttributeView):
    def name(self) -> str: ...
    def readAttributes(self) -> DosFileAttributes: ...
    def setArchive(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHidden(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setReadOnly(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSystem(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class DosFileAttributes(BasicFileAttributes):
    def isArchive(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def isSystem(self) -> bool: ...

_FileAttribute__T = typing.TypeVar('_FileAttribute__T')  # <T>
class FileAttribute(java.lang.Object, typing.Generic[_FileAttribute__T]):
    def name(self) -> str: ...
    def value(self) -> _FileAttribute__T: ...

class FileAttributeView(AttributeView): ...

class FileOwnerAttributeView(FileAttributeView):
    def getOwner(self) -> UserPrincipal: ...
    def name(self) -> str: ...
    def setOwner(self, arg1: UserPrincipal, /) -> None: ...

class FileStoreAttributeView(AttributeView): ...

class FileTime(java.lang.Comparable[FileTime]):
    def compareTo(self, other: FileTime, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMillis(value: int | java.jlong | java.lang.Long, /) -> FileTime: ...
    @typing.overload
    @staticmethod
    def from_(instant: java.time.Instant, /) -> FileTime: ...
    @typing.overload
    @staticmethod
    def from_(value: int | java.jlong | java.lang.Long, unit: java.util.concurrent.TimeUnit, /) -> FileTime: ...
    def hashCode(self) -> int: ...
    def to(self, unit: java.util.concurrent.TimeUnit, /) -> int: ...
    def toInstant(self) -> java.time.Instant: ...
    def toMillis(self) -> int: ...
    def toString(self) -> str: ...

class GroupPrincipal(UserPrincipal): ...

class PosixFileAttributeView(BasicFileAttributeView, FileOwnerAttributeView):
    def name(self) -> str: ...
    def readAttributes(self) -> PosixFileAttributes: ...
    def setGroup(self, arg1: GroupPrincipal, /) -> None: ...
    def setPermissions(self, arg1: java.util.Set[PosixFilePermission], /) -> None: ...

class PosixFileAttributes(BasicFileAttributes):
    def group(self) -> GroupPrincipal: ...
    def owner(self) -> UserPrincipal: ...
    def permissions(self) -> java.util.Set[PosixFilePermission]: ...

class PosixFilePermission(java.lang.Enum[PosixFilePermission]):
    GROUP_EXECUTE: typing.ClassVar[PosixFilePermission] = ...
    GROUP_READ: typing.ClassVar[PosixFilePermission] = ...
    GROUP_WRITE: typing.ClassVar[PosixFilePermission] = ...
    OTHERS_EXECUTE: typing.ClassVar[PosixFilePermission] = ...
    OTHERS_READ: typing.ClassVar[PosixFilePermission] = ...
    OTHERS_WRITE: typing.ClassVar[PosixFilePermission] = ...
    OWNER_EXECUTE: typing.ClassVar[PosixFilePermission] = ...
    OWNER_READ: typing.ClassVar[PosixFilePermission] = ...
    OWNER_WRITE: typing.ClassVar[PosixFilePermission] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> PosixFilePermission: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[PosixFilePermission]: ...

class PosixFilePermissions(java.lang.Object):
    @staticmethod
    def asFileAttribute(perms: java.util.Set[PosixFilePermission], /) -> FileAttribute[java.util.Set[PosixFilePermission]]: ...
    @staticmethod
    def fromString(perms: str | java.lang.String, /) -> java.util.Set[PosixFilePermission]: ...
    @staticmethod
    def toString(perms: java.util.Set[PosixFilePermission], /) -> str: ...

class UserDefinedFileAttributeView(FileAttributeView):
    def delete(self, arg1: str | java.lang.String, /) -> None: ...
    def list(self) -> java.util.List[java.lang.String]: ...
    def name(self) -> str: ...
    def read(self, arg1: str | java.lang.String, arg2: java.nio.ByteBuffer, /) -> int: ...
    def size(self, arg1: str | java.lang.String, /) -> int: ...
    def write(self, arg1: str | java.lang.String, arg2: java.nio.ByteBuffer, /) -> int: ...

class UserPrincipal(java.security.Principal): ...

class UserPrincipalLookupService(java.lang.Object):
    def __init__(self) -> None: ...
    def lookupPrincipalByGroupName(self, arg1: str | java.lang.String, /) -> GroupPrincipal: ...
    def lookupPrincipalByName(self, arg1: str | java.lang.String, /) -> UserPrincipal: ...

class UserPrincipalNotFoundException(java.io.IOException):
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    def getName(self) -> str: ...



import typing

import android.app
import android.content
import android.os
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class AlternativeSpan(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AlternativeSpan]] = ...
    def __init__(self, startPosition: int | java.jint | java.lang.Integer, endPosition: int | java.jint | java.lang.Integer, alternatives: java.util.List[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAlternatives(self) -> java.util.List[java.lang.String]: ...
    def getEndPosition(self) -> int: ...
    def getStartPosition(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AlternativeSpans(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AlternativeSpans]] = ...
    def __init__(self, spans: java.util.List[AlternativeSpan], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSpans(self) -> java.util.List[AlternativeSpan]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ModelDownloadListener(java.lang.Object):
    def onError(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProgress(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onScheduled(self) -> None: ...
    def onSuccess(self) -> None: ...

class RecognitionListener(java.lang.Object):
    def onBeginningOfSpeech(self) -> None: ...
    def onBufferReceived(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onEndOfSegmentedSession(self) -> None: ...
    def onEndOfSpeech(self) -> None: ...
    def onError(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onEvent(self, arg1: int | java.jint | java.lang.Integer, arg2: android.os.Bundle, /) -> None: ...
    def onLanguageDetection(self, results: android.os.Bundle, /) -> None: ...
    def onPartialResults(self, arg1: android.os.Bundle, /) -> None: ...
    def onReadyForSpeech(self, arg1: android.os.Bundle, /) -> None: ...
    def onResults(self, arg1: android.os.Bundle, /) -> None: ...
    def onRmsChanged(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def onSegmentResults(self, segmentResults: android.os.Bundle, /) -> None: ...

class RecognitionPart(android.os.Parcelable):
    CONFIDENCE_LEVEL_HIGH: typing.ClassVar[int] = ...
    CONFIDENCE_LEVEL_LOW: typing.ClassVar[int] = ...
    CONFIDENCE_LEVEL_MEDIUM: typing.ClassVar[int] = ...
    CONFIDENCE_LEVEL_MEDIUM_HIGH: typing.ClassVar[int] = ...
    CONFIDENCE_LEVEL_MEDIUM_LOW: typing.ClassVar[int] = ...
    CONFIDENCE_LEVEL_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RecognitionPart]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getConfidenceLevel(self) -> int: ...
    def getFormattedText(self) -> str | None: ...
    def getRawText(self) -> str: ...
    def getTimestampMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, rawText: str | java.lang.String, /) -> None: ...
        def build(self) -> RecognitionPart: ...
        def setConfidenceLevel(self, value: int | java.jint | java.lang.Integer, /) -> RecognitionPart.Builder: ...
        def setFormattedText(self, value: str | java.lang.String, /) -> RecognitionPart.Builder: ...
        def setRawText(self, value: str | java.lang.String, /) -> RecognitionPart.Builder: ...
        def setTimestampMillis(self, value: int | java.jlong | java.lang.Long, /) -> RecognitionPart.Builder: ...

class RecognitionService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def createContext(self, contextParams: android.content.ContextParams, /) -> android.content.Context: ...
    def getMaxConcurrentSessionsCount(self) -> int: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCancel(self, arg1: RecognitionService.Callback, /) -> None: ...
    @typing.overload
    def onCheckRecognitionSupport(self, recognizerIntent: android.content.Intent, supportCallback: RecognitionService.SupportCallback, /) -> None: ...
    @typing.overload
    def onCheckRecognitionSupport(self, recognizerIntent: android.content.Intent, attributionSource: android.content.AttributionSource, supportCallback: RecognitionService.SupportCallback, /) -> None: ...
    def onDestroy(self) -> None: ...
    def onStartListening(self, arg1: android.content.Intent, arg2: RecognitionService.Callback, /) -> None: ...
    def onStopListening(self, arg1: RecognitionService.Callback, /) -> None: ...
    @typing.overload
    def onTriggerModelDownload(self, recognizerIntent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onTriggerModelDownload(self, recognizerIntent: android.content.Intent, attributionSource: android.content.AttributionSource, /) -> None: ...
    @typing.overload
    def onTriggerModelDownload(self, recognizerIntent: android.content.Intent, attributionSource: android.content.AttributionSource, listener: ModelDownloadListener, /) -> None: ...

    class SupportCallback(java.lang.Object):
        def onError(self, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSupportResult(self, recognitionSupport: RecognitionSupport, /) -> None: ...

    class Callback(java.lang.Object):
        def beginningOfSpeech(self) -> None: ...
        def bufferReceived(self, buffer: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def endOfSegmentedSession(self) -> None: ...
        def endOfSpeech(self) -> None: ...
        def error(self, error: int | java.jint | java.lang.Integer, /) -> None: ...
        def getCallingAttributionSource(self) -> android.content.AttributionSource: ...
        def getCallingUid(self) -> int: ...
        def languageDetection(self, results: android.os.Bundle, /) -> None: ...
        def partialResults(self, partialResults: android.os.Bundle, /) -> None: ...
        def readyForSpeech(self, params: android.os.Bundle, /) -> None: ...
        def results(self, results: android.os.Bundle, /) -> None: ...
        def rmsChanged(self, rmsdB: float | java.jfloat | java.lang.Float, /) -> None: ...
        def segmentResults(self, results: android.os.Bundle, /) -> None: ...

class RecognitionSupport(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RecognitionSupport]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInstalledOnDeviceLanguages(self) -> java.util.List[java.lang.String]: ...
    def getOnlineLanguages(self) -> java.util.List[java.lang.String]: ...
    def getPendingOnDeviceLanguages(self) -> java.util.List[java.lang.String]: ...
    def getSupportedOnDeviceLanguages(self) -> java.util.List[java.lang.String]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addInstalledOnDeviceLanguage(self, value: str | java.lang.String, /) -> RecognitionSupport.Builder: ...
        def addOnlineLanguage(self, value: str | java.lang.String, /) -> RecognitionSupport.Builder: ...
        def addPendingOnDeviceLanguage(self, value: str | java.lang.String, /) -> RecognitionSupport.Builder: ...
        def addSupportedOnDeviceLanguage(self, value: str | java.lang.String, /) -> RecognitionSupport.Builder: ...
        def build(self) -> RecognitionSupport: ...
        def setInstalledOnDeviceLanguages(self, value: java.util.List[java.lang.String], /) -> RecognitionSupport.Builder: ...
        def setOnlineLanguages(self, value: java.util.List[java.lang.String], /) -> RecognitionSupport.Builder: ...
        def setPendingOnDeviceLanguages(self, value: java.util.List[java.lang.String], /) -> RecognitionSupport.Builder: ...
        def setSupportedOnDeviceLanguages(self, value: java.util.List[java.lang.String], /) -> RecognitionSupport.Builder: ...

class RecognitionSupportCallback(java.lang.Object):
    def onError(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSupportResult(self, arg1: RecognitionSupport, /) -> None: ...

class RecognizerIntent(java.lang.Object):
    ACTION_GET_LANGUAGE_DETAILS: typing.ClassVar[str] = ...
    ACTION_RECOGNIZE_SPEECH: typing.ClassVar[str] = ...
    ACTION_VOICE_SEARCH_HANDS_FREE: typing.ClassVar[str] = ...
    ACTION_WEB_SEARCH: typing.ClassVar[str] = ...
    DETAILS_META_DATA: typing.ClassVar[str] = ...
    EXTRA_AUDIO_INJECT_SOURCE: typing.ClassVar[str] = ...
    EXTRA_AUDIO_SOURCE: typing.ClassVar[str] = ...
    EXTRA_AUDIO_SOURCE_CHANNEL_COUNT: typing.ClassVar[str] = ...
    EXTRA_AUDIO_SOURCE_ENCODING: typing.ClassVar[str] = ...
    EXTRA_AUDIO_SOURCE_SAMPLING_RATE: typing.ClassVar[str] = ...
    EXTRA_BIASING_STRINGS: typing.ClassVar[str] = ...
    EXTRA_CALLING_PACKAGE: typing.ClassVar[str] = ...
    EXTRA_CONFIDENCE_SCORES: typing.ClassVar[str] = ...
    EXTRA_ENABLE_BIASING_DEVICE_CONTEXT: typing.ClassVar[str] = ...
    EXTRA_ENABLE_FORMATTING: typing.ClassVar[str] = ...
    EXTRA_ENABLE_LANGUAGE_DETECTION: typing.ClassVar[str] = ...
    EXTRA_ENABLE_LANGUAGE_SWITCH: typing.ClassVar[str] = ...
    EXTRA_HIDE_PARTIAL_TRAILING_PUNCTUATION: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE_DETECTION_ALLOWED_LANGUAGES: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE_MODEL: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE_PREFERENCE: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE_SWITCH_ALLOWED_LANGUAGES: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE_SWITCH_INITIAL_ACTIVE_DURATION_TIME_MILLIS: typing.ClassVar[str] = ...
    EXTRA_LANGUAGE_SWITCH_MAX_SWITCHES: typing.ClassVar[str] = ...
    EXTRA_MASK_OFFENSIVE_WORDS: typing.ClassVar[str] = ...
    EXTRA_MAX_RESULTS: typing.ClassVar[str] = ...
    EXTRA_ONLY_RETURN_LANGUAGE_PREFERENCE: typing.ClassVar[str] = ...
    EXTRA_ORIGIN: typing.ClassVar[str] = ...
    EXTRA_PARTIAL_RESULTS: typing.ClassVar[str] = ...
    EXTRA_PREFER_OFFLINE: typing.ClassVar[str] = ...
    EXTRA_PROMPT: typing.ClassVar[str] = ...
    EXTRA_REQUEST_WORD_CONFIDENCE: typing.ClassVar[str] = ...
    EXTRA_REQUEST_WORD_TIMING: typing.ClassVar[str] = ...
    EXTRA_RESULTS: typing.ClassVar[str] = ...
    EXTRA_RESULTS_PENDINGINTENT: typing.ClassVar[str] = ...
    EXTRA_RESULTS_PENDINGINTENT_BUNDLE: typing.ClassVar[str] = ...
    EXTRA_SECURE: typing.ClassVar[str] = ...
    EXTRA_SEGMENTED_SESSION: typing.ClassVar[str] = ...
    EXTRA_SPEECH_INPUT_COMPLETE_SILENCE_LENGTH_MILLIS: typing.ClassVar[str] = ...
    EXTRA_SPEECH_INPUT_MINIMUM_LENGTH_MILLIS: typing.ClassVar[str] = ...
    EXTRA_SPEECH_INPUT_POSSIBLY_COMPLETE_SILENCE_LENGTH_MILLIS: typing.ClassVar[str] = ...
    EXTRA_SUPPORTED_LANGUAGES: typing.ClassVar[str] = ...
    EXTRA_WEB_SEARCH_ONLY: typing.ClassVar[str] = ...
    FORMATTING_OPTIMIZE_LATENCY: typing.ClassVar[str] = ...
    FORMATTING_OPTIMIZE_QUALITY: typing.ClassVar[str] = ...
    LANGUAGE_MODEL_FREE_FORM: typing.ClassVar[str] = ...
    LANGUAGE_MODEL_WEB_SEARCH: typing.ClassVar[str] = ...
    LANGUAGE_SWITCH_BALANCED: typing.ClassVar[str] = ...
    LANGUAGE_SWITCH_HIGH_PRECISION: typing.ClassVar[str] = ...
    LANGUAGE_SWITCH_QUICK_RESPONSE: typing.ClassVar[str] = ...
    RESULT_AUDIO_ERROR: typing.ClassVar[int] = ...
    RESULT_CLIENT_ERROR: typing.ClassVar[int] = ...
    RESULT_NETWORK_ERROR: typing.ClassVar[int] = ...
    RESULT_NO_MATCH: typing.ClassVar[int] = ...
    RESULT_SERVER_ERROR: typing.ClassVar[int] = ...
    @staticmethod
    def getVoiceDetailsIntent(context: android.content.Context, /) -> android.content.Intent | None: ...

class RecognizerResultsIntent(java.lang.Object):
    ACTION_VOICE_SEARCH_RESULTS: typing.ClassVar[str] = ...
    EXTRA_VOICE_SEARCH_RESULT_HTML: typing.ClassVar[str] = ...
    EXTRA_VOICE_SEARCH_RESULT_HTML_BASE_URLS: typing.ClassVar[str] = ...
    EXTRA_VOICE_SEARCH_RESULT_HTTP_HEADERS: typing.ClassVar[str] = ...
    EXTRA_VOICE_SEARCH_RESULT_STRINGS: typing.ClassVar[str] = ...
    EXTRA_VOICE_SEARCH_RESULT_URLS: typing.ClassVar[str] = ...
    URI_SCHEME_INLINE: typing.ClassVar[str] = ...

class SpeechRecognizer(java.lang.Object):
    CONFIDENCE_SCORES: typing.ClassVar[str] = ...
    DETECTED_LANGUAGE: typing.ClassVar[str] = ...
    ERROR_AUDIO: typing.ClassVar[int] = ...
    ERROR_CANNOT_CHECK_SUPPORT: typing.ClassVar[int] = ...
    ERROR_CANNOT_LISTEN_TO_DOWNLOAD_EVENTS: typing.ClassVar[int] = ...
    ERROR_CLIENT: typing.ClassVar[int] = ...
    ERROR_INSUFFICIENT_PERMISSIONS: typing.ClassVar[int] = ...
    ERROR_LANGUAGE_NOT_SUPPORTED: typing.ClassVar[int] = ...
    ERROR_LANGUAGE_UNAVAILABLE: typing.ClassVar[int] = ...
    ERROR_NETWORK: typing.ClassVar[int] = ...
    ERROR_NETWORK_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_NO_MATCH: typing.ClassVar[int] = ...
    ERROR_RECOGNIZER_BUSY: typing.ClassVar[int] = ...
    ERROR_SERVER: typing.ClassVar[int] = ...
    ERROR_SERVER_DISCONNECTED: typing.ClassVar[int] = ...
    ERROR_SPEECH_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_TOO_MANY_REQUESTS: typing.ClassVar[int] = ...
    LANGUAGE_DETECTION_CONFIDENCE_LEVEL: typing.ClassVar[str] = ...
    LANGUAGE_DETECTION_CONFIDENCE_LEVEL_CONFIDENT: typing.ClassVar[int] = ...
    LANGUAGE_DETECTION_CONFIDENCE_LEVEL_HIGHLY_CONFIDENT: typing.ClassVar[int] = ...
    LANGUAGE_DETECTION_CONFIDENCE_LEVEL_NOT_CONFIDENT: typing.ClassVar[int] = ...
    LANGUAGE_DETECTION_CONFIDENCE_LEVEL_UNKNOWN: typing.ClassVar[int] = ...
    LANGUAGE_SWITCH_RESULT: typing.ClassVar[str] = ...
    LANGUAGE_SWITCH_RESULT_FAILED: typing.ClassVar[int] = ...
    LANGUAGE_SWITCH_RESULT_NOT_ATTEMPTED: typing.ClassVar[int] = ...
    LANGUAGE_SWITCH_RESULT_SKIPPED_NO_MODEL: typing.ClassVar[int] = ...
    LANGUAGE_SWITCH_RESULT_SUCCEEDED: typing.ClassVar[int] = ...
    RECOGNITION_PARTS: typing.ClassVar[str] = ...
    RESULTS_ALTERNATIVES: typing.ClassVar[str] = ...
    RESULTS_RECOGNITION: typing.ClassVar[str] = ...
    TOP_LOCALE_ALTERNATIVES: typing.ClassVar[str] = ...
    def cancel(self) -> None: ...
    def checkRecognitionSupport(self, recognizerIntent: android.content.Intent, executor: java.util.concurrent.Executor, supportListener: RecognitionSupportCallback, /) -> None: ...
    @staticmethod
    def createOnDeviceSpeechRecognizer(context: android.content.Context, /) -> SpeechRecognizer: ...
    @typing.overload
    @staticmethod
    def createSpeechRecognizer(context: android.content.Context, /) -> SpeechRecognizer: ...
    @typing.overload
    @staticmethod
    def createSpeechRecognizer(context: android.content.Context, serviceComponent: android.content.ComponentName, /) -> SpeechRecognizer: ...
    def destroy(self) -> None: ...
    @staticmethod
    def isOnDeviceRecognitionAvailable(context: android.content.Context, /) -> bool: ...
    @staticmethod
    def isRecognitionAvailable(context: android.content.Context, /) -> bool: ...
    def setRecognitionListener(self, listener: RecognitionListener, /) -> None: ...
    def startListening(self, recognizerIntent: android.content.Intent, /) -> None: ...
    def stopListening(self) -> None: ...
    @typing.overload
    def triggerModelDownload(self, recognizerIntent: android.content.Intent, /) -> None: ...
    @typing.overload
    def triggerModelDownload(self, recognizerIntent: android.content.Intent, executor: java.util.concurrent.Executor, listener: ModelDownloadListener, /) -> None: ...
